==> design-system-previewer-1.0.0.tgz: package/index.js <==
const path = require('path')
const Task = require('data.task')
const futurize = require('futurize').futurize(Task)
const { Map, fromJS } = require('immutable')

const createApp = require('./server/app')
const createSocket = require('./server/socket')
const createParser = require('@salesforce-ux/design-system-parser')
const createReducer = require('./server/reducers')

const rootPath = path.resolve.bind(path, __dirname)

const refresh = ({ getComments, getMarkup }) =>
  getComments()
    .map(createParser)
    .map(parser =>
      createReducer(parser, { getMarkup })
    )

const setup = ({ app, io, getComments, getMarkup }) => {
  getComments = futurize(getComments)
  getMarkup = futurize(getMarkup)
  let reducer
  let state = Map()
  const dispatch = action => {
    reducer(state, fromJS(action)).fork(
      error => {
        console.log(error)
        io.emit('error', error)
      },
      nextState => {
        state = nextState
        io.emit('setState', state.toJS())
      }
    )
  }
  app.get('/preview/:component', (req, res) => {
    dispatch({
      type: 'componentSelected',
      payload: {
        component: req.params.component
      }
    })
    return res.sendFile(rootPath('public/index.html'))
  })
  io.on('connection', socket => {
    socket.emit('setState', state)
    socket.on('dispatch', dispatch)
  })
  return event => {
    switch (event) {
      case 'comments':
        return refresh({ getComments, getMarkup }).fork(
          e => console.log(e),
          r => {
            reducer = r
            state.get('component') // already on a page?
            ? dispatch({ type: 'commentsChanged' })
            : dispatch({ type: 'initialize' })
          }
        )
      case 'markup':
        return dispatch({
          type: 'variantSelected',
          payload: {
            variant: state.getIn(['variant', 'id'])
          }
        })
      case 'styles':
        return dispatch({
          type: 'cssChanged',
          payload: {}
        })
    }
  }
}

module.exports = ({ publicPath, cssUrl, getComments, getMarkup }) => {
  const app = createApp({ publicPath, cssUrl })
  return {
    listen: (port, ready) => {
      const server = app.listen(port, () => {
        const io = createSocket(server)
        const emit = setup({ app, io, getComments, getMarkup })
        emit('comments')
        ready({ server, emit })
      })
    }
  }
}

==> design-system-previewer-1.0.2.tgz: package/index.js <==
const path = require('path')
const Task = require('data.task')
const futurize = require('futurize').futurize(Task)
const { Map, fromJS } = require('immutable')

const createApp = require('./server/app')
const createSocket = require('./server/socket')
const createParser = require('@salesforce-ux/design-system-parser')
const createReducer = require('./server/reducers')

const rootPath = path.resolve.bind(path, __dirname)

const refresh = ({ getComments, getMarkup }) =>
  getComments()
    .map(createParser)
    .map(parser =>
      createReducer(parser, { getMarkup })
    )

const setup = ({ app, io, getComments, getMarkup }) => {
  getComments = futurize(getComments)
  getMarkup = futurize(getMarkup)
  let reducer
  let state = Map()
  const dispatch = action => {
    reducer(state, fromJS(action)).fork(
      error => {
        console.log(error)
        io.emit('error', error)
      },
      nextState => {
        state = nextState
        io.emit('setState', state.toJS())
      }
    )
  }
  app.get('/preview', (req, res) => {
    dispatch({
      type: 'loadFromUrl',
      payload: {
        component: req.query.component,
        variant: req.query.variant,
        modifiers: req.query.modifiers,
        formFactor: req.query.formFactor,
        bgColor: req.query.bgColor
      }
    })
    return res.sendFile(rootPath('public/index.html'))
  })
  io.on('connection', socket => {
    socket.emit('setState', state)
    socket.on('dispatch', dispatch)
  })
  return event => {
    switch (event) {
      case 'comments':
        return refresh({ getComments, getMarkup }).fork(
          e => console.log(e),
          r => {
            reducer = r
            state.get('component') // already on a page?
            ? dispatch({ type: 'commentsChanged' })
            : dispatch({ type: 'initialize' })
          }
        )
      case 'markup':
        return dispatch({
          type: 'variantSelected',
          payload: {
            variant: state.getIn(['variant', 'id'])
          }
        })
      case 'styles':
        return dispatch({
          type: 'cssChanged',
          payload: {}
        })
    }
  }
}

module.exports = ({ publicPath, cssUrl, getComments, getMarkup }) => {
  const app = createApp({ publicPath, cssUrl })
  return {
    listen: (port, ready) => {
      const server = app.listen(port, () => {
        const io = createSocket(server)
        const emit = setup({ app, io, getComments, getMarkup })
        emit('comments')
        ready({ server, emit })
      })
    }
  }
}
